@@ -1,6 +1,6 @@
 package Log::Log4perl::Tiny;
 {
-  $Log::Log4perl::Tiny::VERSION = '1.2.5_2';
+  $Log::Log4perl::Tiny::VERSION = '1.2.5_3';
 }
 
 # ABSTRACT: mimic Log::Log4perl in one single module
@@ -210,6 +210,16 @@ sub format {
 
 *layout = \&format;
 
+sub emit_log {
+   my ($self, $message) = @_;
+   my $fh = $self->{fh};
+   for my $channel ((ref($fh) eq 'ARRAY') ? (@$fh) : ($fh)) {
+      (ref($channel) eq 'CODE') ? $channel->($message, $self)
+                                : print {$channel} $message;
+   }
+   return;
+}
+
 sub log {
    my $self = shift;
    return if $self->{level} == $DEAD;
@@ -224,13 +234,7 @@ sub log {
    my $message = sprintf $self->{format},
      map { $format_for{$_}[1]->(\%data_for); } @{$self->{args}};
 
-   my $fh = $self->{fh};
-   for my $channel ((ref($fh) eq 'ARRAY') ? (@$fh) : ($fh)) {
-      (ref($channel) eq 'CODE') ? $channel->($message, $self)
-                                : print {$channel} $message;
-   }
-
-   return;
+   return $self->emit_log($message);
 } ## end sub log
 
 sub ALWAYS { return $_instance->log($OFF, @_); }
@@ -563,7 +567,7 @@ Log::Log4perl::Tiny - mimic Log::Log4perl in one single module
 
 =head1 VERSION
 
-version 1.2.5_2
+version 1.2.5_3
 
 =head1 SYNOPSIS
 
@@ -1272,6 +1276,11 @@ The main logging function is actually the following:
 the first parameter is the log level, the rest is the message to log
 apart from references to subroutines that are first evaluated
 
+=item C<< emit_log >>
+
+emit the message in the first positional parameter to all logging
+channels
+
 =back
 
 Additionally, you have the following accessors:
